@@ -15,7 +15,7 @@ from conans.model.ref import ConanFileReference
 from conans.model.graph_lock import GraphLockFile
 from sense2.client.cmd.create import create
 from conans.client.graph.graph_manager import GraphManager
-from sense2.client.loader import ConanFileLoader
+from conans.client.loader import ConanFileLoader
 
 
 default_manifest_folder = default_manifest_folder_co
